summaryrefslogtreecommitdiffstats
path: root/c/src/lib/libcpu/arm/lpc22xx/timer/timer.c
diff options
context:
space:
mode:
Diffstat (limited to 'c/src/lib/libcpu/arm/lpc22xx/timer/timer.c')
-rw-r--r--c/src/lib/libcpu/arm/lpc22xx/timer/timer.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/c/src/lib/libcpu/arm/lpc22xx/timer/timer.c b/c/src/lib/libcpu/arm/lpc22xx/timer/timer.c
index f0bf7cab96..8bc3547763 100644
--- a/c/src/lib/libcpu/arm/lpc22xx/timer/timer.c
+++ b/c/src/lib/libcpu/arm/lpc22xx/timer/timer.c
@@ -13,8 +13,8 @@
* Notes:
* This file manages the benchmark timer used by the RTEMS Timing Test
* Suite. Each measured time period is demarcated by calls to
* Timer_initialize() and Read_timer(). Read_timer() usually returns
* the number of microseconds since Timer_initialize() exitted.
*
* It is important that the timer start/stop overhead be determined
* when porting or modifying this code.
@@ -29,19 +29,19 @@
uint32_t g_start;
uint32_t g_freq;
-rtems_boolean Timer_driver_Find_average_overhead;
+rtems_boolean benchmark_timerfind_average_overhead;
/*
* Set up Timer 1
*/
-void Timer_initialize( void )
+void benchmark_timerinitialize( void )
{
g_freq = LPC22xx_Fpclk / 1000;
}
/*
* The following controls the behavior of Read_timer().
*
* AVG_OVEREHAD is the overhead for starting and stopping the timer. It
* is usually deducted from the number returned.
@@ -55,7 +55,7 @@ void Timer_initialize( void )
/* This value is in microseconds. */
#define LEAST_VALID 1 /* Don't trust a clicks value lower than this */
-int Read_timer( void )
+int benchmark_timerread( void )
{
return (T0TC/(LPC22xx_Fpclk/1000000));
/*
@@ -70,15 +70,15 @@ int Read_timer( void )
* in Timing Test Suite.
*/
-rtems_status_code Empty_function( void )
+rtems_status_code benchmark_timerempty_function( void )
{
return RTEMS_SUCCESSFUL;
}
-void Set_find_average_overhead(
+void benchmark_timerdisable_subtracting_average_overhead(
rtems_boolean find_flag
)
{
- Timer_driver_Find_average_overhead = find_flag;
+ benchmark_timerfind_average_overhead = find_flag;
}
@@ -13,8 +13,8 @@
* This file manages the benchmark timer used by the RTEMS Timing Test
* Suite. Each measured time period is demarcated by calls to
- * Timer_initialize() and Read_timer(). Read_timer() usually returns
- * the number of microseconds since Timer_initialize() exitted.
+ * benchmark_timerinitialize() and benchmark_timerread(). benchmark_timerread() usually returns
+ * the number of microseconds since benchmark_timerinitialize() exitted.
*
* It is important that the timer start/stop overhead be determined
@@ -29,19 +29,19 @@
}
/*
- * The following controls the behavior of Read_timer().
+ * The following controls the behavior of benchmark_timerread().
*
* AVG_OVEREHAD is the overhead for starting and stopping the timer. It